@@ -1,8 +1,8 @@
 #' @title State- and territory-level diversity
-#' 
+#'
 #' @description
-#' For Australian states and territories, use geographic distribution data from 
-#' the APC to calculate state-level diversity for native, introduced, 
+#' For Australian states and territories, use geographic distribution data from
+#' the APC to calculate state-level diversity for native, introduced,
 #' and more complicated species origins
 #'
 #' @family diversity methods
@@ -26,6 +26,7 @@
 #'
 #' @examples
 #'  \donttest{state_diversity_counts(state = "NSW")}
+
 state_diversity_counts <- function(state,
                                    resources = load_taxonomic_resources()) {
   
@@ -77,14 +78,45 @@ state_diversity_counts <- function(state,
 
 
 #' @noRd
-get_apc_genus_family_lookup <-
-  function(resources = load_taxonomic_resources()) {
-    apc_s <- dplyr::filter(resources$APC,
-                    taxon_rank == "species")
-    dplyr::tibble(genus = word(apc_s$scientific_name, 1, 1),
-           family = apc_s$family) %>%
+create_apc_genus_family_lookup <-
+  function(resources) {
+    apc_s <- dplyr::filter(resources$APC, taxon_rank == "species")
+    dplyr::tibble(genus = word(apc_s$accepted_name_usage, 1, 1),
+                  family = apc_s$family) |>
       dplyr::distinct() -> lu
     return(lu)
   }
 
-
+#' @title Lookup Family by Genus from APC
+#'
+#' @description
+#' Retrieve the family name for a given genus using taxonomic data from the
+#' Australian Plant Census (APC).
+#'
+#' @param genus A character vector of genus names for which to retrieve the
+#'  corresponding family names.
+#' @param resources The taxonomic resources required to make the lookup. 
+#'  Loading this can be slow, so call \code{\link{load_taxonomic_resources}} 
+#'  separately to speed up this function and pass the resources in.
+#'
+#' @return A data frame with two columns: "genus", indicating the genus name, 
+#'  and "family", indicating the corresponding family name from the APC.
+#'
+#' @seealso \code{\link{load_taxonomic_resources}}
+#'
+#' @export
+#'
+#' @examples
+#'  \donttest{get_apc_genus_family_lookup(genus = c("Acacia", "Eucalyptus"))}
+get_apc_genus_family_lookup <-
+  function(genus, resources = load_taxonomic_resources()) {
+    if (is.null(resources)) {
+      message("Not finding taxonomic resources; check internet connection?")
+      return(NULL)
+    }
+    fam_lu <- create_apc_genus_family_lookup(resources = resources)
+    lu <- dplyr::tibble(genus = genus) %>%
+      dplyr::left_join(fam_lu, by = "genus")
+    if (any(is.na(lu$family))) warning("some non-matches with the APC accepted genus list, check the formatting of your genus vector.")
+    return(lu)
+  }
